@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27.9-159.fc10.src.rpm ]
+if [ ! -r kernel-2.6.27.12-170.2.5.fc10.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/development/source/SRPMS/kernel-2.6.27.9-159.fc10.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/development/source/SRPMS/kernel-2.6.27.12-170.2.5.fc10.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27.9-159.fc10.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.27.12-170.2.5.fc10.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.5-20081225.tar.gz ]
+if [ ! -r ccs-patch-1.6.6-20090202.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.5-20081225.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090202.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /root/rpmbuild/SPECS/kernel.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel.spec	2008-12-17 03:48:30.000000000 +0900
-+++ kernel.spec	2008-12-25 09:20:33.000000000 +0900
+--- kernel.spec	2009-01-21 15:16:42.000000000 +0900
++++ kernel.spec	2009-01-27 16:48:33.000000000 +0900
 @@ -12,7 +12,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -#% define buildid .local
-+%define buildid _tomoyo_1.6.5
++%define buildid _tomoyo_1.6.6
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
@@ -66,7 +66,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -850,7 +855,7 @@
+@@ -841,7 +846,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -75,18 +75,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1360,6 +1365,10 @@
+@@ -1343,6 +1348,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.5-20081225.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.6-20090202.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.27-fedora-10.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1386,6 +1395,9 @@
+@@ -1369,6 +1378,9 @@
  for i in *.config
  do
    mv $i .config
