@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Free Mandatory Access Control.
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.3   2008/07/15
+ * Version: 1.6.6   2009/02/02
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -85,15 +85,21 @@ static int update_no_umount_acl(const char *dir, const bool is_delete)
  */
 int ccs_may_umount(struct vfsmount *mnt)
 {
-	int error = -EPERM;
+	struct ccs_request_info r;
+	int error;
 	const char *dir0;
-	const u8 mode = ccs_check_flags(CCS_SAKURA_RESTRICT_UNMOUNT);
-	const bool is_enforce = (mode == 3);
+	bool is_enforce;
 	struct no_umount_entry *ptr;
 	struct path_info dir;
 	bool found = false;
-	if (!mode)
+	if (!ccs_can_sleep())
 		return 0;
+	ccs_init_request_info(&r, NULL, CCS_SAKURA_RESTRICT_UNMOUNT);
+	is_enforce = (r.mode == 3);
+	if (!r.mode)
+		return 0;
+ retry:
+	error = -EPERM;
 	dir0 = ccs_realpath_from_dentry(mnt->mnt_root, mnt);
 	if (!dir0)
 		goto out;
@@ -111,11 +117,10 @@ int ccs_may_umount(struct vfsmount *mnt)
 		const char *exename = ccs_get_exe();
 		printk(KERN_WARNING "SAKURA-%s: umount %s "
 		       "(pid=%d:exe=%s): Permission denied.\n",
-		       ccs_get_msg(is_enforce), dir0, current->pid,
+		       ccs_get_msg(is_enforce), dir0, (pid_t) sys_getpid(),
 		       exename);
 		if (is_enforce)
-			error = ccs_check_supervisor(NULL,
-						     "# %s is requesting\n"
+			error = ccs_check_supervisor(&r, "# %s is requesting\n"
 						     "unmount %s\n",
 						     exename, dir0);
 		ccs_free(exename);
@@ -125,6 +130,8 @@ int ccs_may_umount(struct vfsmount *mnt)
  out:
 	if (!is_enforce)
 		error = 0;
+	if (error == 1)
+		goto retry;
 	return error;
 }
 
