@@ -3,9 +3,9 @@
  *
  * Implementation of the Tamper-Proof Device Filesystem.
  *
- * Portions Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Portions Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.4   2008/09/03
+ * Version: 1.6.6   2009/02/02
  *
  * This file is applicable to 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -84,7 +84,7 @@ static struct inode *syaoran_get_inode(struct super_block *sb, int mode,
 		inode->i_uid = current->fsuid;
 		inode->i_gid = current->fsgid;
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
-#if !defined(RHEL_MAJOR) || RHEL_MAJOR != 5
+#ifndef HAVE_NO_I_BLKSIZE_IN_INODE
 		inode->i_blksize = PAGE_CACHE_SIZE;
 #endif
 #endif
